uim.model API documentation
Description: Package for the UIM model. This package contains the data model for the UIM.

# Module `uim.model`

Package for the UIM model. This package contains the data model for the UIM.

Expand source code

    # -*- coding: utf-8 -*-
    """
    Package for the UIM model.
    This package contains the data model for the UIM.
    """

    __all__ = ['helpers', 'inkdata', 'inkinput', 'semantics',  'ink']

    import uim.model.helpers
    import uim.model.inkdata
    import uim.model.inkinput
    import uim.model.semantics
    import uim.model.ink

## Sub-modules

`uim.model.base`
`uim.model.helpers`

  Helpers

  The helpers are simple functions to support with: …

`uim.model.ink`
`uim.model.inkdata`

  Ink Data

  Contains all data structures which are relevant for representing the visual appearance: …

`uim.model.inkinput`

  Input Data

  The input data consists of input data configuration the device and its sensor channels producing sensor data. The sensor data …

`uim.model.semantics`